<#
.Description
    PowerShell script progettato per connettersi ad Active Directory, elencare tutti i gruppi in una tabella con ID incrementale e nome, consentire all'utente di selezionare un gruppo, recuperare tutti i membri di quel gruppo insieme allo stato attivo/inattivo di ciascun membro, e infine salvare queste informazioni in un file CSV.
.Author
    Roberto Bonfa'
.Version
    1.3
#>


Import-Module ActiveDirectory

# Connect to Active Directory and get groups
try {
    $groups = Get-ADGroup -Filter * -ErrorAction Stop
} catch {
    Write-Host "Errore durante la connessione ad Active Directory: $_"
    return
}

# Create and display table
$table = New-Object -TypeName System.Data.DataTable
$table.Columns.Add("ID", [int]) | Out-Null
$table.Columns.Add("Name", [string]) | Out-Null

$counter = 1
foreach ($group in $groups) {
    $row = $table.NewRow()
    $row.ID = $counter
    $row.Name = $group.Name
    $table.Rows.Add($row)
    $counter++
}

$table | Format-Table -AutoSize

# User input for group selection
do {
    $groupSelection = Read-Host "Inserisci l'ID del gruppo che desideri selezionare."
    $selectedGroup = $table | Where-Object {$_.ID -eq $groupSelection} | Select-Object -ExpandProperty Name
} while (-not $selectedGroup)

# Get members and their status
try {
    $members = Get-ADGroupMember -Identity $selectedGroup -ErrorAction Stop | Where-Object { $_.objectClass -eq 'user' }
    $users = foreach ($member in $members) {
        $user = Get-ADUser -Identity $member
        [PSCustomObject]@{
            Name = $user.Name
            Enabled = if ($user.Enabled) { "Active" } else { "Inactive" }
        }
    }

    # Save to CSV
    $csvFileName = [System.IO.Path]::GetInvalidFileNameChars() -replace '','_' -replace ' ','_' -join ''
    $users | Export-Csv -Path ".\$selectedGroup_$csvFileName.csv" -NoTypeInformation
    Write-Host "File CSV salvato come '$selectedGroup_$csvFileName.csv'"
} catch {
    Write-Host "Errore durante il recupero dei membri del gruppo: $_"
}